@@ -38,6 +38,7 @@
 
 #define COGL_HAS_GLIB_SUPPORT 1
 #define COGL_HAS_GTYPE_SUPPORT 1
+#define COGL_HAS_COGL_PATH_SUPPORT 1
 #define COGL_HAS_GL 1
 #define CLUTTER_COGL_HAS_GL 1
 #define COGL_HAS_GLX_SUPPORT 1
@@ -45,10 +46,11 @@
 #define COGL_HAS_X11_SUPPORT 1
 #define COGL_HAS_XLIB 1
 #define COGL_HAS_XLIB_SUPPORT 1
+#define COGL_HAS_POLL_SUPPORT 1
 
 #define COGL_VERSION_MAJOR_INTERNAL 1
-#define COGL_VERSION_MINOR_INTERNAL 14
-#define COGL_VERSION_MICRO_INTERNAL 0
-#define COGL_VERSION_STRING_INTERNAL "1.14.0"
+#define COGL_VERSION_MINOR_INTERNAL 16
+#define COGL_VERSION_MICRO_INTERNAL 2
+#define COGL_VERSION_STRING_INTERNAL "1.16.2"
 
 #endif
